pub struct MWPMDecoder { /* private fields */ }Expand description
Minimum Weight Perfect Matching decoder for surface codes (legacy).
This is a simplified decoder kept for backward compatibility.
For production use with the rotated surface code, use MwpmSurfaceDecoder.
Implementations
Sourceimpl MWPMDecoder
impl MWPMDecoder
Sourcepub const fn new(surface_code: SurfaceCode) -> Self
pub const fn new(surface_code: SurfaceCode) -> Self
Create MWPM decoder for surface code.
Sourcepub fn decode_syndrome(
&self,
x_syndrome: &[bool],
z_syndrome: &[bool],
) -> QuantRS2Result<PauliString>
pub fn decode_syndrome( &self, x_syndrome: &[bool], z_syndrome: &[bool], ) -> QuantRS2Result<PauliString>
Find minimum weight matching for syndrome.