pub struct TeleportationProtocol {
pub noise: f64,
pub rng_seed: u64,
}Expand description
Single-hop quantum teleportation protocol.
Fields
noise: f64Depolarizing noise probability applied to each qubit of the resource Bell pair.
rng_seed: u64Seed for the random number generator.
Implementations
Sourceimpl TeleportationProtocol
impl TeleportationProtocol
Sourcepub fn teleport(
&self,
state: [Complex64; 2],
) -> QuantRS2Result<TeleportationResult>
pub fn teleport( &self, state: [Complex64; 2], ) -> QuantRS2Result<TeleportationResult>
Run the teleportation protocol for the given input state.
state must be a normalised 2-component complex vector.