pub fn par_range(
start: usize,
end: usize,
) -> impl ParallelIterator<Item = usize>Expand description
Helper function to create a parallel iterator from a range
pub fn par_range(
start: usize,
end: usize,
) -> impl ParallelIterator<Item = usize>Helper function to create a parallel iterator from a range