pub struct QuantumChannel {
pub input_dim: usize,
pub output_dim: usize,
pub kraus: Option<KrausRepresentation>,
pub choi: Option<ChoiRepresentation>,
pub stinespring: Option<StinespringRepresentation>,
/* private fields */
}Expand description
A quantum channel represented in various forms
Fields
input_dim: usizeNumber of input qubits
output_dim: usizeNumber of output qubits
kraus: Option<KrausRepresentation>Kraus operator representation
choi: Option<ChoiRepresentation>Choi matrix representation
stinespring: Option<StinespringRepresentation>Stinespring dilation representation
Implementations
Sourceimpl QuantumChannel
impl QuantumChannel
Sourcepub fn from_kraus(operators: Vec<Array2<Complex<f64>>>) -> QuantRS2Result<Self>
pub fn from_kraus(operators: Vec<Array2<Complex<f64>>>) -> QuantRS2Result<Self>
Create a new quantum channel from Kraus operators
Sourcepub fn from_choi(matrix: Array2<Complex<f64>>) -> QuantRS2Result<Self>
pub fn from_choi(matrix: Array2<Complex<f64>>) -> QuantRS2Result<Self>
Create a quantum channel from a Choi matrix.
This constructor assumes a square channel, i.e. equal input and output
dimensions (input_dim == output_dim == d). The Choi matrix of such a
channel has dimension total_dim = d * d, so requiring total_dim to be
a perfect square is the correct, exact constraint for this case (it is
not a placeholder approximation). Rectangular channels (d_in != d_out)
are not constructed through this entry point.
Sourcepub fn to_kraus(&mut self) -> QuantRS2Result<&KrausRepresentation>
pub fn to_kraus(&mut self) -> QuantRS2Result<&KrausRepresentation>
Convert to Kraus representation
Sourcepub fn to_choi(&mut self) -> QuantRS2Result<&ChoiRepresentation>
pub fn to_choi(&mut self) -> QuantRS2Result<&ChoiRepresentation>
Convert to Choi representation
Sourcepub fn to_stinespring(&mut self) -> QuantRS2Result<&StinespringRepresentation>
pub fn to_stinespring(&mut self) -> QuantRS2Result<&StinespringRepresentation>
Convert to Stinespring representation
Sourcepub fn apply(
&mut self,
rho: &Array2<Complex<f64>>,
) -> QuantRS2Result<Array2<Complex<f64>>>
pub fn apply( &mut self, rho: &Array2<Complex<f64>>, ) -> QuantRS2Result<Array2<Complex<f64>>>
Apply the channel to a density matrix
Sourcepub fn is_unitary(&mut self) -> QuantRS2Result<bool>
pub fn is_unitary(&mut self) -> QuantRS2Result<bool>
Check if channel is unitary
Sourcepub fn is_depolarizing(&mut self) -> QuantRS2Result<bool>
pub fn is_depolarizing(&mut self) -> QuantRS2Result<bool>
Check if channel is a depolarizing channel
Sourcepub fn depolarizing_parameter(&mut self) -> QuantRS2Result<Option<f64>>
pub fn depolarizing_parameter(&mut self) -> QuantRS2Result<Option<f64>>
Get the depolarizing parameter if this is a depolarizing channel