pub fn inner_product(
state1: &[Complex64],
state2: &[Complex64],
) -> QuantRS2Result<Complex64>Expand description
Compute the inner product of two quantum state vectors
This computes ⟨ψ|φ⟩ = Σ conj(ψ[i]) * φ[i]
pub fn inner_product(
state1: &[Complex64],
state2: &[Complex64],
) -> QuantRS2Result<Complex64>Compute the inner product of two quantum state vectors
This computes ⟨ψ|φ⟩ = Σ conj(ψ[i]) * φ[i]