Module synthesis

Module synthesis 

Gate synthesis from unitary matrices

This module provides algorithms to decompose arbitrary unitary matrices into sequences of quantum gates, including:

  • Single-qubit unitary decomposition (ZYZ, XYX, etc.)
  • Two-qubit unitary decomposition (KAK/Cartan)
  • General n-qubit synthesis using Cosine-Sine decomposition

Structs

SingleQubitDecomposition
Result of single-qubit decomposition

Functions

decompose_single_qubit_xyx
Decompose a single-qubit unitary into XYX rotations
decompose_single_qubit_zyz
Decompose a single-qubit unitary into ZYZ rotations
decompose_two_qubit_kak
Decompose a two-qubit unitary using KAK decomposition
identify_gate
Check if a unitary is close to a known gate
kak_to_gates
Convert KAK decomposition to gate sequence
single_qubit_gates
Convert single-qubit decomposition to gate sequence
synthesize_unitary
Synthesize an arbitrary unitary matrix into quantum gates

Type Aliases

KAKDecomposition
Result of two-qubit KAK decomposition (alias for CartanDecomposition)